Module time

Module time 

Time-related utilities

Functions

boot_time_to_system_time
Convert boot time (from eBPF bpf_ktime_get_ns()) to system time (nanoseconds since UNIX epoch).
system_time_nanos
Get the current system time in nanoseconds since UNIX epoch
system_time_secs
Get the current system time in seconds since UNIX epoch