Event type definitions for profiling data
These types represent the raw events collected by eBPF programs and processed by the agent.
Structs
- CpuSample
- CPU profiling sample event
- GpuKernel
Event - GPU kernel execution event
- Lock
Event - Lock contention event
- Syscall
Event - Syscall event
Enums
- Profile
Event - Unified profiling event type
Type Aliases
- CpuId
- CPU core number
- Pid
- Process ID
- Stack
Trace - Stack trace represented as an array of instruction pointers
- Tid
- Thread ID
- Timestamp
- Timestamp in nanoseconds since boot