Time-related utilities
Functions
- boot_
time_ to_ system_ time - Convert boot time (from eBPF
bpf_ktime_get_ns()) to system time (nanoseconds since UNIX epoch). - system_
time_ nanos - Get the current system time in nanoseconds since UNIX epoch
- system_
time_ secs - Get the current system time in seconds since UNIX epoch